@@ -88,10 +88,10 @@ occuMulti <- function(detformulas, stateformulas,  data, maxOrder,
 
   #Likelihood function in C----------------------------------------------------
   nll_C <- function(params) {
-    .Call("nll_occuMulti",
+    nll_occuMulti(
           fStart-1, fStop-1, t_dmF, dmOcc, params, dmDet, dStart-1, dStop-1,
-          y, yStart-1, yStop-1, Iy0, as.matrix(z), fixed0, penalty, 0,
-          PACKAGE = "unmarked")
+          y, yStart-1, yStop-1, Iy0, as.matrix(z), fixed0, penalty
+          )
   }
   #----------------------------------------------------------------------------
 
@@ -169,13 +169,11 @@ occuMultiLogLik <- function(fit, data){
   dmF <- Matrix::Matrix(dm$dmF, sparse=TRUE)
   t_dmF <- Matrix::t(dmF)
 
-  out <- .Call("nll_occuMulti",
+  out <- nll_occuMulti_loglik(
           dm$fStart-1, dm$fStop-1, t_dmF,
           dm$dmOcc, coef(fit), dm$dmDet, dm$dStart-1, dm$dStop-1, dm$y,
-          dm$yStart-1, dm$yStop-1, dm$Iy0, as.matrix(dm$z), dm$fixed0, 0,
-          #return site likelihoods
-          1,
-          PACKAGE = "unmarked")
+          dm$yStart-1, dm$yStop-1, dm$Iy0, as.matrix(dm$z), dm$fixed0
+          )
 
   as.vector(out)
 
